@@ -2,6 +2,8 @@
 Testing framework for OWWidgets
 """
 import os
+import sys
+import pickle
 import tempfile
 
 import time
@@ -19,6 +21,7 @@ from AnyQt.QtWidgets import (
 )
 
 from orangewidget.report.owreport import OWReport
+from orangewidget.settings import SettingsHandler
 from orangewidget.widget import OWBaseWidget
 
 sip.setdestroyonexit(False)
@@ -159,6 +162,14 @@ class GuiTest(unittest.TestCase):
         global app
         if app is None:
             app = QApplication([])
+        super().setUpClass()
+
+    @classmethod
+    def tearDownClass(cls) -> None:
+        if "pyqtgraph" in sys.modules:
+            import pyqtgraph
+            pyqtgraph.setConfigOption("exitCleanup", False)
+        super().tearDownClass()
 
 
 class WidgetTest(GuiTest):
@@ -680,5 +691,25 @@ def open_widget_classes():
         yield
 
 
+@contextmanager
+def override_default_settings(widget, defaults=None, handler=None):
+    if defaults is None:
+        defaults = {}
+
+    h = (handler or SettingsHandler)()
+    h.widget_class = widget
+    h.defaults = defaults
+    filename = h._get_settings_filename()
+
+    os.makedirs(os.path.dirname(filename), exist_ok=True)
+    with open(filename, "wb") as f:
+        pickle.dump(defaults, f)
+
+    yield
+
+    if os.path.isfile(filename):
+        os.remove(filename)
+
+
 if __name__ == "__main__":
     unittest.main()
